@@ -2,11 +2,10 @@
 # @Author  : llc
 # @Time    : 2022/11/30 14:55
 
-from typing import Optional
 
 from pydantic import BaseModel, Field
 
-from flask_openapi3 import OpenAPI, APIView
+from flask_openapi3 import APIView, OpenAPI
 
 app = OpenAPI(__name__)
 api_view = APIView(url_prefix="/api/v1")
@@ -17,29 +16,28 @@ class Query(BaseModel):
 
 
 class BookQuery(BaseModel):
-    age: Optional[int] = Field(None, description='Age')
+    age: int | None = Field(None, description="Age")
 
 
 class BookBody(BaseModel):
-    age: Optional[int] = Field(..., ge=2, le=4, description='Age')
-    author: str = Field(None, min_length=2, max_length=4, description='Author')
+    age: int | None = Field(..., ge=2, le=4, description="Age")
+    author: str = Field(None, min_length=2, max_length=4, description="Author")
 
 
-@app.get('/open/api')
+@app.get("/open/api")
 async def get_openapi(query: Query):
     print(query)
-    return 'GET, OpenAPI!'
+    return "GET, OpenAPI!"
 
 
-@app.post('/open/api')
+@app.post("/open/api")
 async def post_openapi(body: Query):
     print(body)
-    return 'POST, OpenAPI!'
+    return "POST, OpenAPI!"
 
 
 @api_view.route("/book")
 class BookListAPIView:
-
     @api_view.doc(summary="get book list")
     async def get(self, query: BookQuery):
         return query.model_dump_json()
@@ -52,5 +50,5 @@ class BookListAPIView:
 
 app.register_api_view(api_view)
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     app.run(debug=True)
