@@ -3,8 +3,7 @@
 # @Time    : 2021/5/10 17:01
 from pydantic import BaseModel
 
-from flask_openapi3 import Info, Tag
-from flask_openapi3 import OpenAPI
+from flask_openapi3 import Info, OpenAPI, Tag
 
 info = Info(title="book API", version="1.0.0")
 app = OpenAPI(__name__, info=info)
@@ -27,8 +26,8 @@ def get_book(query: BookQuery):
         "message": "ok",
         "data": [
             {"bid": 1, "age": query.age, "author": query.author},
-            {"bid": 2, "age": query.age, "author": query.author}
-        ]
+            {"bid": 2, "age": query.age, "author": query.author},
+        ],
     }
 
 
