@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 # @Author  : llc
 # @Time    : 2023/7/4 9:47
-from typing import Optional
 
 from pydantic import BaseModel
 
@@ -11,11 +10,9 @@ class OAuthFlow(BaseModel):
     https://spec.openapis.org/oas/v3.1.0#oauth-flow-object
     """
 
-    authorizationUrl: Optional[str] = None
-    tokenUrl: Optional[str] = None
-    refreshUrl: Optional[str] = None
+    authorizationUrl: str | None = None
+    tokenUrl: str | None = None
+    refreshUrl: str | None = None
     scopes: dict[str, str]
 
-    model_config = {
-        "extra": "allow"
-    }
+    model_config = {"extra": "allow"}
