@@ -7,7 +7,7 @@ from pydantic import BaseModel
 
 from flask_openapi3 import Info, OpenAPI
 
-info = Info(title='book API', version='1.0.0')
+info = Info(title="book API", version="1.0.0")
 
 app = OpenAPI(__name__, info=info)
 app.config["TESTING"] = True
@@ -28,13 +28,13 @@ def client():
     return client
 
 
-@app.post('/book')
+@app.post("/book")
 def create_book(body: CreateBookBody):
     print(body.model_dump())
     return {"code": 0, "message": "ok"}
 
 
 def test_post(client):
-    resp = client.post("/book", json={'aaa': 111, 'bbb': 222})
+    resp = client.post("/book", json={"aaa": 111, "bbb": 222})
     print(resp.json)
     assert resp.status_code == 200
