@@ -2,7 +2,7 @@
 # @Author  : llc
 # @Time    : 2023/8/6 13:47
 from enum import Enum
-from typing import Union, Any
+from typing import Any
 
 import pytest
 from pydantic import BaseModel
@@ -49,9 +49,9 @@ class FormParameters(BaseModel):
     parameter: MetadataParameter
     parameter_dict: dict[str, MetadataParameter]
     parameter_list: list[MetadataParameter]
-    parameter_list_union: list[Union[bool, float, str, int, FileType, MetadataParameter]]
-    parameter_union: Union[MetadataParameter, MetadataParameter2]
-    union_all: Union[str, int, float, bool, FileType, MetadataParameter]
+    parameter_list_union: list[bool | float | str | int | FileType | MetadataParameter]
+    parameter_union: MetadataParameter | MetadataParameter2
+    union_all: str | int | float | bool | FileType | MetadataParameter
     none: None = None
     default_value: str = "default_value"
 
@@ -62,20 +62,16 @@ class FormParameter(BaseModel):
     model_config = dict(
         openapi_extra={
             "encoding": {
-                "historyMetadata": {
-                    "contentType": "application/xml; charset=utf-8"
-                },
+                "historyMetadata": {"contentType": "application/xml; charset=utf-8"},
                 "profileImage": {
                     "contentType": "image/png, image/jpeg",
                     "headers": {
                         "X-Rate-Limit-Limit": {
                             "description": "The number of allowed requests in the current period",
-                            "schema": {
-                                "type": "integer"
-                            }
+                            "schema": {"type": "integer"},
                         }
-                    }
-                }
+                    },
+                },
             }
         }
     )
@@ -95,6 +91,7 @@ def invalid_json_in_form_example(form: FormParameter):
 
 def test_openapi(client):
     from io import BytesIO
+
     data = {
         "boolean": "true",
         "boolean_list": [True, False],
@@ -109,13 +106,13 @@ def test_openapi(client):
         "obj": '{"a": 2}',
         "parameter": '{"tag": "string"}',
         "parameter_dict": '{"additionalProp1": {"tag": "string"}, "additionalProp2": {"tag": "string"},'
-                          '"additionalProp3": {"tag": "string"}}',
+        '"additionalProp3": {"tag": "string"}}',
         "parameter_list": ['{"tag": "string"}', '{"tag": "string"}'],
         "parameter_list_union": ["ok", '{"tag": "string"}', "7.8"],
         "parameter_union": '{"tag2": "string"}',
         "union_all": "true",
         "string": "a",
-        "string_list": ["a", "b", "c"]
+        "string_list": ["a", "b", "c"],
     }
     resp = client.post("/example", data=data, content_type="multipart/form-data")
     print(resp.text)
@@ -123,15 +120,11 @@ def test_openapi(client):
 
 
 def test_invalid_json_in_form_example(client):
-    data = {
-        "obj": "{a: 2}"
-    }
+    data = {"obj": "{a: 2}"}
     resp = client.post("/example2", data=data, content_type="multipart/form-data")
     assert resp.status_code == 422
 
-    data = {
-        "obj": '{"a": 2}'
-    }
+    data = {"obj": '{"a": 2}'}
 
     resp = client.post("/example2", data=data, content_type="multipart/form-data")
     assert resp.status_code == 200
