@@ -42,35 +42,25 @@ def client():
     return client
 
 
-@app.post('/api/v1/sellouts',
-          tags=[Tag(name='Sellout', description='Loren.')],
-          responses={'200': SelloutList}
-          )
+@app.post("/api/v1/sellouts", tags=[Tag(name="Sellout", description="Loren.")], responses={"200": SelloutList})
 def post_sellout(body: SelloutList):
     print(body)
     return body.model_dump_json()
 
 
-@app.post('/api/v2/sellouts',
-          tags=[Tag(name='Sellout', description='Loren.')],
-          responses={'200': SelloutDict}
-          )
+@app.post("/api/v2/sellouts", tags=[Tag(name="Sellout", description="Loren.")], responses={"200": SelloutDict})
 def post_sellout2(body: SelloutDict):
     print(body)
     return body.model_dump_json()
 
 
-@app.post('/api/v3/sellouts',
-          tags=[Tag(name='Sellout', description='Loren.')]
-          )
+@app.post("/api/v3/sellouts", tags=[Tag(name="Sellout", description="Loren.")])
 def post_sellout3(body: SelloutDict2):
     print(body)
     return body.model_dump_json()
 
 
-@app.post('/api/v4/sellouts',
-          tags=[Tag(name='Sellout', description='Loren.')]
-          )
+@app.post("/api/v4/sellouts", tags=[Tag(name="Sellout", description="Loren.")])
 def post_sellout4(body: SelloutDict3):
     print(body)
     return body.model_dump_json()
