@@ -6,16 +6,11 @@ from __future__ import annotations
 import pytest
 from pydantic import BaseModel, Field
 
-from flask_openapi3 import Info
-from flask_openapi3 import OpenAPI
+from flask_openapi3 import Info, OpenAPI
 
-info = Info(title='book API', version='1.0.0')
+info = Info(title="book API", version="1.0.0")
 
-jwt = {
-    "type": "http",
-    "scheme": "bearer",
-    "bearerFormat": "JWT"
-}
+jwt = {"type": "http", "scheme": "bearer", "bearerFormat": "JWT"}
 security_schemes = {"jwt": jwt}
 
 
@@ -24,13 +19,9 @@ class NotFoundResponse(BaseModel):
     message: str = Field("Resource not found!", description="Exception Information")
 
 
-doc_prefix = '/v1/openapi'
+doc_prefix = "/v1/openapi"
 app = OpenAPI(
-    __name__,
-    info=info,
-    doc_prefix=doc_prefix,
-    security_schemes=security_schemes,
-    responses={"404": NotFoundResponse}
+    __name__, info=info, doc_prefix=doc_prefix, security_schemes=security_schemes, responses={"404": NotFoundResponse}
 )
 app.config["TESTING"] = True
 
