@@ -3,9 +3,11 @@
 # @Time    : 2025/1/15 9:58
 import pytest
 
-from flask_openapi3 import APIBlueprint, OpenAPI, APIView
+from flask_openapi3 import APIBlueprint, APIView, OpenAPI
 
-app = OpenAPI(__name__, )
+app = OpenAPI(
+    __name__,
+)
 app.config["TESTING"] = True
 
 
@@ -47,7 +49,9 @@ class BookAPIView:
 @api_view2.route("/book")
 class BookAPIView2:
     @api_view2.doc(summary="get book")
-    def get(self, ):
+    def get(
+        self,
+    ):
         return "ok"
 
 
